Description Usage Arguments Value
Creates an object with an optional label which stores the originating source data for downstream ggconsort cohorts
1 | cohort_start(.data, label = NULL)
|
.data |
A data frame or tibble |
label |
A character string to describe the set of cohorts |
Returns a ggconsort_cohort object with
$data and $labels items
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.