R/cohort_start.R
cohort_start.Rd
Creates an object with an optional label which stores the originating source data for downstream ggconsort cohorts
cohort_start(.data, label = NULL)
A data frame or tibble
A character string to describe the set of cohorts
Returns a ggconsort_cohort object with $data and $labels items
ggconsort_cohort
$data
$labels
trial_data |> cohort_start("Assessed for eligibility") #> A ggconsort cohort of 1200 observations with 0 cohorts.